==> openwebbeans-1.7.6-source-release.zip: openwebbeans-1.7.6/webbeans-impl/src/main/java/org/apache/webbeans/container/ExternalScope.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.webbeans.container;


import java.lang.annotation.Annotation;

import org.apache.webbeans.config.DefaultAnnotation;


/**
 * A wrapper for an external scope which can be added by
 * {@link javax.enterprise.inject.spi.BeforeBeanDiscovery#addScope(Class, boolean, boolean)}.
 */
public class ExternalScope
{

    private Class<? extends Annotation> scope;
    private boolean normal;
    private boolean passivating;
    private Annotation scopeAnnotation;
    
    public ExternalScope(Class<? extends Annotation> scope, boolean normal, boolean passivating)
    {
        this.scope = scope;
        this.normal = normal;
        this.passivating = passivating;
        scopeAnnotation = DefaultAnnotation.of(scope);
    }

    public Class<? extends Annotation> getScope() 
    {
        return scope;
    }

    public boolean isNormal() 
    {
        return normal;
    }

    public boolean isPassivating() 
    {
        return passivating;
    }
    
    /**
     * @return an instance of the annotation class we got set 
     *         in {@link javax.enterprise.inject.spi.BeforeBeanDiscovery#addScope(Class, boolean, boolean)}
     */
    public Annotation getScopeAnnotation()
    {
        return scopeAnnotation;
    }
}

==> openwebbeans-4.0.3-source-release.zip: openwebbeans-4.0.3/webbeans-impl/src/main/java/org/apache/webbeans/container/ExternalScope.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.webbeans.container;


import java.lang.annotation.Annotation;

import org.apache.webbeans.config.DefaultAnnotation;


/**
 * A wrapper for an external scope which can be added by
 * {@link jakarta.enterprise.inject.spi.BeforeBeanDiscovery#addScope(Class, boolean, boolean)}.
 */
public class ExternalScope
{

    private Class<? extends Annotation> scope;
    private boolean normal;
    private boolean passivating;
    private Annotation scopeAnnotation;
    
    public ExternalScope(Class<? extends Annotation> scope, boolean normal, boolean passivating)
    {
        this.scope = scope;
        this.normal = normal;
        this.passivating = passivating;
        scopeAnnotation = DefaultAnnotation.of(scope);
    }

    public Class<? extends Annotation> getScope() 
    {
        return scope;
    }

    public boolean isNormal() 
    {
        return normal;
    }

    public boolean isPassivating() 
    {
        return passivating;
    }
    
    /**
     * @return an instance of the annotation class we got set 
     *         in {@link jakarta.enterprise.inject.spi.BeforeBeanDiscovery#addScope(Class, boolean, boolean)}
     */
    public Annotation getScopeAnnotation()
    {
        return scopeAnnotation;
    }
}
